@@ -1,6 +1,9 @@
 from typing import Optional
 
 import urwid
+from deltachat import Chat
+
+from ..util import create_message
 
 
 class ChatListContainer(urwid.WidgetPlaceholder):
@@ -49,20 +52,23 @@ class MessageSendContainer(urwid.WidgetPlaceholder):
             text = edit.get_edit_text().strip()
             if not text:
                 return None
+            current_chat = self.root.account.current_chat
             if text.startswith("//"):
                 text = text[1:]
             elif text.startswith("/"):
-                text = self.process_command(text)
-                if text is not None:
-                    edit.set_edit_text(text)
+                edit.set_edit_text(self.process_command(current_chat, text))
                 self.resize_zone(size)
                 return None
-            current_chat = self.root.account.current_chat
             if current_chat.is_contact_request():
                 # accept contact requests automatically until UI allows to accept/block
                 current_chat.accept()
-            current_chat.send_text(text)
-            edit.set_edit_text("")
+            try:
+                current_chat.send_text(text)
+                edit.set_edit_text("")
+            except ValueError:
+                edit.set_edit_text(
+                    "Error: message could not be sent, are you a member of the chat?"
+                )
             self.resize_zone(size)
         # give the focus to the chat list
         elif key == self.keymap["left"]:
@@ -105,33 +111,58 @@ class MessageSendContainer(urwid.WidgetPlaceholder):
         if rows_needed != size[1]:
             contents[1] = (contents[1][0], ("given", rows_needed))
 
-    def process_command(self, cmd) -> Optional[str]:
+    def process_command(self, chat: Chat, cmd: str) -> str:
         model = self.root.account
         acc = model.account
         args = cmd.split(maxsplit=1)
+
+        text = ""
         if args[0] == "/query":
             self.msg_send_widget.widgetEdit.set_edit_text("")
-            chat = acc.create_chat(args[1].strip())
-            model.select_chat_by_id(chat.id)
-            return None
-        if args[0] == "/join":
+            try:
+                chat = acc.create_chat(args[1].strip())
+                model.select_chat_by_id(chat.id)
+            except AssertionError:
+                text = "Error: invalid email address"
+            except ValueError as ex:
+                text = f"Error: {ex}"
+        elif args[0] == "/join":
             self.msg_send_widget.widgetEdit.set_edit_text("")
             chat = acc.create_group_chat(args[1].strip())
             model.select_chat_by_id(chat.id)
-            return None
-        if args[0] == "/delete":
+        elif args[0] == "/delete":
             self.msg_send_widget.widgetEdit.set_edit_text("")
             model.current_chat.delete()
             model.select_chat(None)
-            return None
-        if args[0] == "/names":
-            return "\n".join(c.addr for c in model.current_chat.get_contacts())
-        if args[0] == "/add":
-            for addr in args[1].split(","):
-                model.current_chat.add_contact(addr.strip())
+        elif args[0] == "/names":
+            text = "\n".join(c.addr for c in model.current_chat.get_contacts())
+        elif args[0] == "/add":
+            try:
+                for addr in args[1].split(","):
+                    model.current_chat.add_contact(addr.strip())
+            except ValueError as ex:
+                text = f"Error: {ex}"
         elif args[0] == "/kick":
-            for addr in args[1].split(","):
-                model.current_chat.remove_contact(addr.strip())
+            try:
+                for addr in args[1].split(","):
+                    model.current_chat.remove_contact(addr.strip())
+            except AttributeError:
+                text = "Error: invalid email address"
+            except ValueError as ex:
+                text = f"Error: {ex}"
         elif args[0] == "/part":
-            model.current_chat.remove_contact(acc.get_self_contact())
-        return f"ERROR: Unknown command {args[0]}"
+            try:
+                model.current_chat.remove_contact(acc.get_self_contact())
+            except ValueError as ex:
+                text = f"Error: {ex}"
+        elif args[0] == "/id":
+            text = str(model.current_chat.id)
+        elif args[0] == "/send":
+            try:
+                chat.send_msg(create_message(chat.account, filename=args[1].strip()))
+            except ValueError as ex:
+                text = f"Error: {ex}"
+        else:
+            text = f"ERROR: Unknown command {args[0]}"
+
+        return text
