@@ -87,10 +87,9 @@ class MessagesWidget(urwid.ListBox, ChatListMonitor):
         )
 
         if not msg.is_text():
+            text = f"[file://{msg.filename}]"
             if msg.text:
-                text = "[File] – " + msg.text
-            else:
-                text = "[File]"
+                text += f" – {msg.text}"
         else:
             text = msg.text
 
@@ -121,12 +120,11 @@ class MessagesWidget(urwid.ListBox, ChatListMonitor):
                             line = line[2:]
                         else:
                             quoting = False
-                    line = ("quote", quote + line)
+                    lines.append(("quote", quote + line))
                 elif sender == me:
-                    line = ("self_msg", line)
+                    lines.append(("self_msg", line))
                 elif mention:
-                    line = ("mention", line)
-                lines.append(line)
+                    lines.append(("mention", line))
             message_text = urwid.Text(lines or "")
 
         message_to_display = urwid.Columns(
